@@ -6,6 +6,7 @@ import random
 import contextlib
 import shutil
 import datetime
+import sys
 
 from .api import TheTVDBApi
 from .action.sync import setup as sync_setup, action as sync_action
@@ -24,9 +25,8 @@ from .utils import write_yaml
 from .utils import read_yaml
 
 from .database import open_database
-from .database import SetDB
 
-__version__ = "0.9.2"
+__version__ = "0.10.1"
 
 # current scheme version.
 SCHEME_VERSION = 2
@@ -316,15 +316,27 @@ def migration_check(ns):
 
     if migrations:
         path = backup_libdir(ns)
-        print ns.C.warning("Backed up library directory to: {}".format(path))
+        ns.out(ns.C.warning("Backed up library directory to: {}".format(path)))
 
         for key, migration in migrations:
-            print ns.C.title("Migrating database version {0}".format(key))
+            ns.out(ns.C.title("Migrating database version {0}".format(key)))
             migration(ns)
 
         db['scheme-version'] = SCHEME_VERSION
 
 
+class Printer(object):
+    def __init__(self, stream, encoding='utf-8'):
+        self._stream = stream
+        self._encoding = encoding
+
+    def __call__(self, string):
+        if not isinstance(string, unicode):
+            raise Exception("Only unicode objects should be used")
+
+        self._stream.write(string.encode(self._encoding) + '\n')
+
+
 def main(args):
     parser = argparse.ArgumentParser(version="ontv " + __version__)
 
@@ -332,6 +344,8 @@ def main(args):
 
     ns = parser.parse_args(args)
 
+    ns.out = Printer(sys.stdout)
+
     logging.basicConfig(format=LOGGING_FORMAT, level=ns.loglevel)
 
     setup_ns(ns)
@@ -356,7 +370,7 @@ def main(args):
         ns.series = SeriesDAO(series, episodes, watched)
 
         if not ns.is_synced and ns.action != sync_action:
-            print ns.t.bold_red("Your first action should be 'sync'")
+            ns.out(ns.t.bold_red("Your first action should be 'sync'"))
             return 1
 
         return ns.action(ns)
