@@ -25,21 +25,21 @@ def parse_datetime(s):
     return datetime.datetime.strptime(s, DATETIME_FORMAT)
 
 
-def pick_one(alternatives, title="Pick one: ", indent="  "):
+def pick_one(out, alternatives, title="Pick one: ", indent="  "):
     while True:
         for i, (alternative, _) in enumerate(alternatives):
-            print u"{0}{1}) {2}".format(indent, i, alternative)
+            out(u"{0}{1}) {2}".format(indent, i, alternative))
 
         try:
             user_input = raw_input(title)
         except EOFError:
-            print "No input"
+            out("No input")
             return None
 
         try:
             user_input = int(user_input)
         except:
-            print "Invalid input '{0}'".format(user_input)
+            out("Invalid input '{0}'".format(user_input))
             continue
 
         if user_input < 0:
@@ -48,14 +48,14 @@ def pick_one(alternatives, title="Pick one: ", indent="  "):
         try:
             _, data = alternatives[user_input]
         except IndexError:
-            print "Invalid index {0}, try one between 0-{1}".format(
-                user_input, len(alternatives) - 1)
+            out("Invalid index {0}, try one between 0-{1}".format(
+                user_input, len(alternatives) - 1))
             continue
 
         return data
 
 
-def find_series_external(fetch_series, series_id):
+def find_series_external(out, fetch_series, series_id):
     results = fetch_series(series_id)
 
     if len(results) <= 0:
@@ -68,15 +68,16 @@ def find_series_external(fetch_series, series_id):
         (u"{0[series_name]} ({0[id]})".format(s), s['id']) for s in results]
 
     return pick_one(
+        out,
         alternatives,
         title="Pick a series (ctrl-d to abort): ")
 
 
-def find_series(fetch_series, series_id):
+def find_series(out, fetch_series, series_id):
     try:
         return int(series_id)
     except:
-        return find_series_external(fetch_series, series_id)
+        return find_series_external(out, fetch_series, series_id)
 
 
 def group_episodes(episodes):
@@ -100,11 +101,11 @@ def sorted_episodes(episodes):
     return sorted(episodes, key=_episode_key)
 
 
-def series_finder(fetch_series, get_series, query_id):
+def series_finder(out, fetch_series, get_series, query_id):
     """
     Find series from the local database.
     """
-    result_id = find_series(fetch_series, query_id)
+    result_id = find_series(out, fetch_series, query_id)
 
     if result_id is None:
         raise Exception(u"no such series: {0}".format(query_id))
@@ -252,7 +253,8 @@ def local_series_finder(ns):
     if ns.series_query is None:
         return None
 
-    return series_finder(ns.series.find_series, ns.series.get, ns.series_query)
+    return series_finder(ns.out, ns.series.find_series, ns.series.get,
+                         ns.series_query)
 
 
 def local_episodes_finder(ns, series):
@@ -280,7 +282,8 @@ def api_series_finder(ns):
     def get_series(series_id):
         return ns.api.series(series_id, ns.language)
 
-    return series_finder(ns.api.getseries, get_series, ns.series_query)
+    return series_finder(ns.out, ns.api.getseries, get_series,
+                         ns.series_query)
 
 
 def with_resource(finder):
@@ -290,7 +293,7 @@ def with_resource(finder):
             try:
                 resource = finder(ns, *args)
             except Exception as e:
-                print ns.t.bold_red(str(e))
+                ns.out(ns.t.bold_red(str(e)))
                 return 1
 
             args = list(args) + [resource]
@@ -319,7 +322,7 @@ def find_episodes(ns, episodes):
             ignored_seasons=ns.ignored_seasons)
 
         if result is None:
-            print ns.t.bold_red(u"no episode is current")
+            ns.out(ns.t.bold_red(u"no episode(s) could be found"))
             return
 
         episode, _ = result
